==> wpewebkit_2.36.0.orig.tar.xz: wpewebkit-2.36.0/Source/WebCore/Modules/WebGPU/GPUImageCopyExternalImage.h <==
/*
 * Copyright (C) 2021-2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUOrigin2DDict.h"
#include "HTMLCanvasElement.h"
#include "ImageBitmap.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUImageCopyExternalImage.h>
#include <variant>
#include <wtf/RefPtr.h>

namespace WebCore {

struct GPUImageCopyExternalImage {
    PAL::WebGPU::ImageCopyExternalImage convertToBacking() const
    {
        return {
            // FIXME: Handle the canvas element.
            origin ? std::optional { WebCore::convertToBacking(*origin) } : std::nullopt,
            flipY,
        };
    }

    std::variant<RefPtr<ImageBitmap>, RefPtr<HTMLCanvasElement>> source;
    std::optional<GPUOrigin2D> origin;
    bool flipY { false };
};

}

==> wpewebkit_2.38.6.orig.tar.xz: wpewebkit-2.38.6/Source/WebCore/Modules/WebGPU/GPUImageCopyExternalImage.h <==
/*
 * Copyright (C) 2021-2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUOrigin2DDict.h"
#include "HTMLCanvasElement.h"
#include "ImageBitmap.h"
#include "OffscreenCanvas.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUImageCopyExternalImage.h>
#include <variant>
#include <wtf/RefPtr.h>

namespace WebCore {

struct GPUImageCopyExternalImage {
#if ENABLE(OFFSCREEN_CANVAS)
    using SourceType = std::variant<RefPtr<ImageBitmap>, RefPtr<HTMLCanvasElement>, RefPtr<OffscreenCanvas>>;
#else
    using SourceType = std::variant<RefPtr<ImageBitmap>, RefPtr<HTMLCanvasElement>>;
#endif

    PAL::WebGPU::ImageCopyExternalImage convertToBacking() const
    {
        return {
            // FIXME: Handle the canvas element.
            origin ? std::optional { WebCore::convertToBacking(*origin) } : std::nullopt,
            flipY,
        };
    }

    SourceType source;
    std::optional<GPUOrigin2D> origin;
    bool flipY { false };
};

}
